# -*- coding: utf-8 -*-

import os

from django import VERSION

PROJECT_ROOT = os.path.normpath(os.path.dirname(__file__))

DATABASE_ENGINE = 'sqlite3'

SITE_ID = 1

SECRET_KEY = 'cb452188a1c017e94f96d9f813ec2bf8'

DATABASES = {
    'default': {
        'ENGINE': 'django.db.backends.sqlite3',
        'NAME': ':memory:',
    }
}

INSTALLED_APPS = [
    'django.contrib.auth',
    'django.contrib.contenttypes',
    'django.contrib.sessions',
    'django.contrib.sites',
    'django.contrib.messages',
    'django.contrib.staticfiles',
    'django.contrib.admin',

    'chatovod',
]

TEMPLATE_LOADERS = (
    'django.template.loaders.filesystem.Loader',
    'django.template.loaders.app_directories.Loader',
)

TEMPLATE_ROOT = '%s/../demo/demo/templates' % PROJECT_ROOT
TEMPLATE_DIRS = (TEMPLATE_ROOT,)

ROOT_URLCONF = 'chatovod.test_urls'

if VERSION[:2] < (1, 6):
    TEST_RUNNER = 'discover_runner.DiscoverRunner'

TEMPLATE_CONTEXT_PROCESSORS = (
    'django.contrib.auth.context_processors.auth',
    'django.core.context_processors.debug',
    'django.core.context_processors.i18n',
    'django.core.context_processors.request',
    'django.core.context_processors.media',
    'django.contrib.messages.context_processors.messages',
    'django.core.context_processors.static',
)



# -*- coding: utf-8 -*-

from django.core.urlresolvers import reverse
from django.contrib.auth.models import User
from chatovod.templatetags import defaults
from django.test.client import Client
from django.test import TestCase


class ChatovodAsyncTestCase(TestCase):
    def _no_auth(self, chat_type=None):
        if chat_type is not None:
            defaults.CHAT_TYPE = chat_type
        client = Client()
        return client.get(reverse("home"))

    def _auth(self, chat_type=None):
        login = 'admin'
        email = 'admin@local.host'
        password = 'password'

        if chat_type is not None:
            defaults.CHAT_TYPE = chat_type

        User.objects.create_superuser(login, email, password)

        client = Client()
        client.login(username=login, password=password)

        return client.get(reverse("home"))

    def _check_auth_params(self, response):
        data_list = [
            'amode=django',
            'anick=admin',
            'width=900',
            'akey=07581c6ee320f0070a2ffabe92aa6550',
            'height=500',
            'aemail=admin%40local.host',
        ]
        for param in data_list:
            self.assertContains(response, param)

    def test_a_async(self):
        response = self._no_auth()
        self.assertContains(response, '<div id="chatovod"></div>')
        self.assertContains(response, '<script type="text/javascript">')
        self.assertContains(
            response, "'http://demo.chatovod.ru/widget.js?width=900&"
                      "height=500&divId=chatovod'")

    def test_b_iframe(self):
        response = self._no_auth('iframe')
        self.assertContains(response, '<iframe')
        self.assertContains(
            response, '"http://demo.chatovod.ru/widget/?width=900&height=500"')

    def test_c_script(self):
        response = self._no_auth('script')
        self.assertContains(response, '<script')
        self.assertContains(
            response,
            '"http://demo.chatovod.ru/widget.js?width=900&height=500"')

    def test_d_async(self):
        response = self._auth('async')
        self.assertContains(response, '<div id="chatovod"></div>')
        self.assertContains(response, '<script type="text/javascript">')
        self._check_auth_params(response)

    def test_e_iframe(self):
        response = self._auth('iframe')
        self.assertContains(response, '<iframe')
        self._check_auth_params(response)

    def test_f_script(self):
        response = self._auth('script')
        self.assertContains(response, '<script')
        self._check_auth_params(response)



# -*- coding: utf-8 -*-

from urllib import urlencode
from hashlib import md5

from django import template

import defaults


register = template.Library()


@register.inclusion_tag('chatovod/chat.html', takes_context=True)
def chatovod(context):
    request = context.get('request')
    if request and request.user.is_authenticated() and defaults.CHAT_API_KEY:
        auth_hash = u'%s%s%s' % (
            request.user.username, request.user.email, defaults.CHAT_API_KEY)
        query = {
            'akey': md5(auth_hash.encode('utf8')).hexdigest(),
            'anick': request.user.username.encode('utf8'),
            'aemail': request.user.email,
            'amode': defaults.CHAT_MODE,
        }
        query.update(defaults.CHAT_QUERY)
    else:
        query = defaults.CHAT_QUERY

    if defaults.CHAT_TYPE == 'iframe':
        chat_url = 'http://%s/widget/?%s'
    else:
        chat_url = 'http://%s/widget.js?%s'

    return {
        'type': defaults.CHAT_TYPE,
        'width': defaults.CHAT_WIDTH,
        'height': defaults.CHAT_HEIGHT,
        'divId': defaults.CHAT_ASYNC_DIV_ID,
        'chat_url': chat_url % (defaults.CHAT_DOMAIN, urlencode(query)),
    }



from setuptools import setup, find_packages
from chatovod import VERSION


setup(
    name='django-chatovod',
    version=".".join(map(str, VERSION)),
    description='Chatovod  - chat widget for Django.',
    keywords="django chat chatovod",
    long_description=open('README.rst').read(),
    author="GoTLiuM InSPiRiT",
    author_email='gotlium@gmail.com',
    url='http://github.com/gotlium/django-chatovod',
    packages=find_packages(exclude=['demo']),
    include_package_data=True,
    package_data={
        'chatovod': [
            'templates/chatovod/*.html',
        ],
    },
    zip_safe=False,
    classifiers=[
        'Development Status :: 5 - Production/Stable',
        'Environment :: Console',
        'Environment :: Web Environment',
        'Framework :: Django',
        'Intended Audience :: Developers',
        'Intended Audience :: System Administrators',
        'License :: OSI Approved :: GNU General Public License (GPL)',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Programming Language :: Python :: 2.6',
        'Programming Language :: Python :: 2.7',
    ],
)



try:
    from django.conf.urls.defaults import patterns, url
except ImportError:
    from django.conf.urls import patterns, url

from django.shortcuts import render


def home(request):
    return render(request, 'home.html')


urlpatterns = patterns(
    '',
    url(r'^$', home, name='home'),
)
